==> senior_design_system-2.2.16.tar.gz: example/lib/pages/pin_code_field.example.dart <==
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';
import '../widgets/panel.dart';

class PinCodeFieldsExample extends StatefulWidget {
  const PinCodeFieldsExample({Key? key}) : super(key: key);

  @override
  State<PinCodeFieldsExample> createState() => _PinCodeFieldsExampleState();
}

class _PinCodeFieldsExampleState extends State<PinCodeFieldsExample> {
  String firstPin = '';
  String secondPin = '';

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Pin Code Fields',
      child: SingleChildScrollView(
        child: Consumer<ThemeRepository>(
          builder: (context, repository, child) => Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Panel(
                title: 'Visible content',
                child: Center(
                  child: Column(
                    children: [
                      SeniorPinCodeFields(
                        allowPasteText: true,
                        autoClear: false,
                        length: 6,
                        onCompleteValidator: (text) async => text == '123456',
                        onComplete: (value) {
                          setState(() {
                            firstPin = value;
                          });
                        },
                        pasteModalDefinitions: SeniorModalDefinitions(
                          title: 'Colar o conteúdo copiado?',
                          content: 'Você deseja colar o conteúdo da área de transferência?',
                          confirmLabel: 'Colar',
                          cancelLabel: 'Cancelar',
                        ),
                      ),
                      SeniorText.label('Conteúdo: $firstPin'),
                    ],
                  ),
                ),
              ),
              Panel(
                title: 'Invisible content',
                child: Center(
                  child: Column(
                    children: [
                      SeniorPinCodeFields(
                        length: 3,
                        obscureText: true,
                        allowPasteText: false,
                        onComplete: (value) {
                          setState(() {
                            secondPin = value;
                          });
                        },
                      ),
                      SeniorText.label('Conteúdo: $secondPin'),
                    ],
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> senior_design_system-6.0.0.tar.gz: example/lib/pages/pin_code_field.example.dart <==
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';
import '../widgets/panel.dart';

class PinCodeFieldsExample extends StatefulWidget {
  const PinCodeFieldsExample({Key? key}) : super(key: key);

  @override
  State<PinCodeFieldsExample> createState() => _PinCodeFieldsExampleState();
}

class _PinCodeFieldsExampleState extends State<PinCodeFieldsExample> {
  String firstPin = '';
  String secondPin = '';

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Pin Code Fields',
      child: SingleChildScrollView(
        child: Consumer<ThemeRepository>(
          builder: (context, repository, child) => Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Panel(
                title: 'Visible content',
                child: Center(
                  child: Column(
                    children: [
                      SeniorPinCodeFields(
                        allowPasteText: true,
                        autoClear: false,
                        length: 6,
                        onCompleteValidator: (text) async => text == '123456',
                        onComplete: (value) {
                          setState(() {
                            firstPin = value;
                          });
                        },
                        pasteModalDefinitions: SeniorModalDefinitions(
                          title: 'Colar o conteúdo copiado?',
                          content:
                              'Você deseja colar o conteúdo da área de transferência?',
                          confirmLabel: 'Colar',
                          cancelLabel: 'Cancelar',
                        ),
                      ),
                      SeniorText.label('Conteúdo: $firstPin'),
                    ],
                  ),
                ),
              ),
              Panel(
                title: 'Invisible content',
                child: Center(
                  child: Column(
                    children: [
                      SeniorPinCodeFields(
                        length: 3,
                        obscureText: true,
                        allowPasteText: false,
                        onComplete: (value) {
                          setState(() {
                            secondPin = value;
                          });
                        },
                      ),
                      SeniorText.label('Conteúdo: $secondPin'),
                    ],
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
